@@ -13,7 +13,7 @@ def Flider():
         print('Continuing...')
     save_paths = ['flask_app/templates/', 'flask_app/config/', 'flask_app/', 'flask_app/static/css/', 'flask_app/static/js/', '']
     file_names = ['index.html', 'mysqlcontroller.py', '__init__.py', 'style.css', 'scripts.js', 'server.py']
-    read_names = ['index.flid', 'mysqlcontroller.flid', 'init.flid', 'style.flid', 'scripts.flid', 'server.flid']
+    read_names = ['index.txt', 'mysqlcontroller.txt', 'init.txt', 'style.txt', 'scripts.txt', 'server.txt']
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
